import { View } from 'react-native';
import { useLinkBuilder } from '@react-navigation/native';
import { PlatformPressable } from '@react-navigation/elements';
import React, { ReactNode } from 'react';
import MenuItem from './menu-item';
import { FullCircleIcon } from './icons/full-circle';
import { EmptyCircleIcon } from './icons/empty-circle';

type IconConfig = {
  [key: string]: {
    active: ReactNode;
    inactive: ReactNode;
  };
};

interface BottomNavigationProps {
  state: any;
  descriptors: any;
  navigation: any;
  icons: IconConfig;
  shadow?: boolean;
  divider?: boolean;
}

const BottomNavigation = ({
  state,
  descriptors,
  navigation,
  icons,
  shadow = false,
  divider = false,
}: BottomNavigationProps) => {
  const { buildHref } = useLinkBuilder();
  const dividerClassFlag = divider ? 'border-t border-gray-100' : '';

  return (
    <View className="h-[86px]" style={{ flexDirection: 'row' }}>
      {state.routes.map((route, index) => {
        const { options } = descriptors[route.key];
        const label = options.tabBarLabel ?? options.title ?? route.name;
        const isFocused = state.index === index;

        const routeIcons = icons[route.name] || {
          active: <FullCircleIcon />,
          inactive: <EmptyCircleIcon />,
        };

        const onPress = () => {
          const event = navigation.emit({
            type: 'tabPress',
            target: route.key,
            canPreventDefault: true,
          });

          if (!isFocused && !event.defaultPrevented) {
            navigation.navigate(route.name, route.params);
          }
        };

        return (
          <PlatformPressable
            key={route.key}
            pressOpacity={1}
            href={buildHref(route.name, route.params)}
            accessibilityState={isFocused ? { selected: true } : {}}
            testID={`${route.name}-tab`}
            onPress={onPress}
            className={`flex-1 ${dividerClassFlag} bg-white justify-center items-center pb-[20px]`}
          >
            <MenuItem
              activeIcon={routeIcons.active}
              idleIcon={routeIcons.inactive}
              menuTitle={label}
              selected={isFocused}
            />
          </PlatformPressable>
        );
      })}
    </View>
  );
};

export default BottomNavigation;
